# package_name

Description. 
The package image_processing is used to:
Processing
	- Histogram matching
	- Structural similarity
Utils:
	- Read Image
	- Save Image
	_ Plot image
	- Plot result
	- Plot histogram

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install package_name

```bash
pip install image-processing-package
```
S

## Author
Jucicaral Pires
## License
[MIT](https://choosealicense.com/licenses/mit/)